package org.openscm.kundo.strategy

/*
 * Copyright (C) 2008 The Ultimate People Company Ltd ("UPCO").
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import org.openscm.kundo.common.logging.SimpleLogger
import org.openscm.kundo.plugins.Module

/**
 * Module Strategy
 * @author <a href="mailto:nigel.garner@upco.co.uk">Nigel Garner</a>
 * @version 1.0.0
 * 
 * Description: An abstraction of the module strategy. 
 * 
 * <p>Abstract module strategy to act as a parent to all concrete implementations of the pattern.</p>
 */
public abstract class ModuleStrategy {
	
	/** List of Modules to be processed**/ 
	protected List<Module> modules
	/** Logger instance **/
	protected final SimpleLogger log
	/** AntBuilder instace **/
	protected AntBuilder ant

	/**
	 * Constructor sets ant instance
	 * @param ant			AntBuilder instance
	 */
	ModuleStrategy( ant ) {
		this.ant = ant
		log = SimpleLogger.getInstance( ant )
		modules = new ArrayList<Module>()
	}
	
	/**
	 * Abstract method where delegates should perform the module loading
	 * @param buildContext	The global ant project
	 * @param childTarget	The ant target to call on child modules
	 * @param inheritConfiguration	Whether the sub module should inherit the properties of the parent project
	 * @param profiles 	A list of profiles to be loaded in the search for modules
	 */
	abstract void loadModules( buildContext, childBuildFile, childTarget , inheritConfiguration, profiles );

}
